AppBuilder

Struct AppBuilder 

pub struct AppBuilder { /* private fields */ }
Builder for App

Implementations

Source

impl AppBuilder

pub fn new() -> AppBuilder

Create a new AppBuilder

pub fn with_config(self, path: &'static str) -> AppBuilder

Set the application config

pub fn with_system<S>(self, sys: S) -> Self
where for<'a> S: System<'a> + Send + 'static,

Register a system in the default gameplay stage (Stage::Update)

pub fn with_system_in_stage<S>(self, stage: Stage, sys: S) -> Self
where for<'a> S: System<'a> + Send + 'static,

Register a system in a specific stage

pub fn with_system_deps<S>(self, sys: S, deps: &'static [&'static str]) -> Self
where for<'a> S: System<'a> + Send + 'static,

Register a system with dependencies in the default gameplay stage

pub fn with_system_deps_in_stage<S>( self, stage: Stage, sys: S, deps: &'static [&'static str], ) -> Self
where for<'a> S: System<'a> + Send + 'static,

Register a system with dependencies in a specific stage

pub fn with_component<C: Component, F: ComponentFactory + Default + 'static>( self, ) -> AppBuilder
where <C as Component>::Storage: Default,

Register a component in the ECS

pub fn with_plugin<C: Plugin + 'static + Send + Sync>( self, plugin: C, ) -> AppBuilder

Register a plugin

pub fn build(self) -> RuntimeResult<App>

Builds an App