PluginBuildContext

Struct PluginBuildContext 

pub struct PluginBuildContext<'a> { /* private fields */ }
Plugin build context

Implementations

Source

impl PluginBuildContext<'_>

pub fn register_system<S>(&mut self, stage: Stage, sys: S)
where for<'a> S: System<'a> + Send + 'static,

Register a system to insert into the dispatcher. Systems will be run in the exact order of registration, and they will be assigned name corresponding to its module path, e.g. game::something::MySystem.

pub fn register_system_deps<S>( &mut self, stage: Stage, sys: S, deps: &'static [&'static str], )
where for<'a> S: System<'a> + Send + 'static,

Register a system to insert into the dispatcher with dependencies. Systems will be run in the exact order of registration, and they will be assigned name corresponding to its module path, e.g. game::something::MySystem.

pub fn insert_resource(&mut self, resource: impl Resource)

Insert a resource into ECS world

pub fn with_component<C: Component, F: ComponentFactory + 'static>( &mut self, name: &'static str, component_factory: F, )
where <C as Component>::Storage: Default,

Register a component in the ECS

pub fn event_sender(&self) -> Sender<AppEvent>

Get an app event sender