Module prelude

Module prelude 

Prelude module

Re-exports

pub use crate::app::App;
pub use crate::app::AppBuilder;

Macros

impl_component_factory
Create and implement a component factory for a component.

Structs

ComponentRegistry
Registry of component name - component factory

Traits

ComponentFactory
All components must have a factory implementing this trait to be able created from a scene config.