Module scenes

Module scenes 

Module providing functionality of scenes Scenes are compositions of entities/components and scripts the user sees on their screen. A scene has a name, a list of scripts it uses (doesn’t actually own them, retrieves from resource manager) and a list of entities (same as with scripts)

Structs

ActiveScene
Runtime state for the currently active scene
ComponentDescriptor
Descriptor of a component in a scene file
EntityDescriptor
Descriptor of an entity in a scene file
Scene
Scene asset
SceneCommands
Scene commands
SceneLibrary
Scene library, handles keyed by name

Enums

SceneCommand
Scene commands