Time

Struct Time 

pub struct Time {
    pub ticks: u64,
    pub tick_period: u64,
    pub total_elapsed_time: f64,
    pub delta_seconds: f64,
}
A struct representing game ticks

Fields

ticks: u64

Amount of ticks ran since the game start

tick_period: u64

The tick rate in nanoseconds per tick

total_elapsed_time: f64

Total elapsed time in seconds

delta_seconds: f64

The duration of the last completed tick in seconds

Implementations

Source

impl Time

pub fn tps(&self) -> f64

Get the current ticks-per-second rate

This function divides total ticks amount by total elapsed time, or if the elapsed time is zero it returns 0.0 to avoid division by zero

pub const fn target_tick_rate(&self) -> f64

Get target TPS