furmint-runtime
The furmint engine’s runtime module, which basically serves as the main entry point into the application (game). Runtime contains only essential pieces: an ECS, time management (ticks), scene management. It “glues” together everything else, you name it: renderer, tiles, sprites, animations, maybe some RPG-like systems.
Previously this was called furmint-engine, but it’s not the actual engine, because the actual engine is a combination
of all crates and plugins. “Runtime” is the best word to describe this crate.
Modules
- app
- Application layer module
- error
- Error handling module
- events
- Module for handling events
- plugins
- Plugins
- prelude
- Prelude module
- scenes
- Module providing functionality of scenes Scenes are compositions of entities/components and scripts the user sees on their screen. A scene has a name, a list of scripts it uses (doesn’t actually own them, retrieves from resource manager) and a list of entities (same as with scripts)
- time
- Module providing time (tick) functionality