pub struct AppBuilder { /* private fields */ }Expand description
Builder for App
Implementations
Sourceimpl AppBuilder
impl AppBuilder
Sourcepub fn new() -> AppBuilder
pub fn new() -> AppBuilder
Create a new AppBuilder
Sourcepub fn with_config(self, path: &'static str) -> AppBuilder
pub fn with_config(self, path: &'static str) -> AppBuilder
Set the application config
Sourcepub fn with_system<S>(self, sys: S) -> Self
pub fn with_system<S>(self, sys: S) -> Self
Register a system in the default gameplay stage (Stage::Update)
Sourcepub fn with_system_in_stage<S>(self, stage: Stage, sys: S) -> Self
pub fn with_system_in_stage<S>(self, stage: Stage, sys: S) -> Self
Register a system in a specific stage
Sourcepub fn with_system_deps<S>(self, sys: S, deps: &'static [&'static str]) -> Self
pub fn with_system_deps<S>(self, sys: S, deps: &'static [&'static str]) -> Self
Register a system with dependencies in the default gameplay stage
Sourcepub fn with_system_deps_in_stage<S>(
self,
stage: Stage,
sys: S,
deps: &'static [&'static str],
) -> Self
pub fn with_system_deps_in_stage<S>( self, stage: Stage, sys: S, deps: &'static [&'static str], ) -> Self
Register a system with dependencies in a specific stage
Sourcepub fn with_component<C: Component, F: ComponentFactory + Default + 'static>(
self,
) -> AppBuilder
pub fn with_component<C: Component, F: ComponentFactory + Default + 'static>( self, ) -> AppBuilder
Register a component in the ECS
Sourcepub fn with_plugin<C: Plugin + 'static + Send + Sync>(
self,
plugin: C,
) -> AppBuilder
pub fn with_plugin<C: Plugin + 'static + Send + Sync>( self, plugin: C, ) -> AppBuilder
Register a plugin
Sourcepub fn build(self) -> RuntimeResult<App>
pub fn build(self) -> RuntimeResult<App>
Builds an App