Plugins
This module provides a simple trait for creating plugins within the furmint engine. Plugins allow extending the capabilities of the engine and also are an essential piece of it, as plugins are the backbone for most of the engine’s features.
An example is the furmint_graphics::plugin::GraphicsPlugin plugin, which provides the most important
part of the engine, the graphics.
Plugin::update
This function is called every tick (60 TPS) in the runtime synchronously, so if:
- your plugin is blocking or does heavy computations and/or
- needs to run independently of the runner thread
consider facilitating the usage of channels and threads.
Structs
- Plugin
Build Context - Plugin build context
- Plugin
Update Context - Plugin update context
Traits
- Plugin
- A trait that all plugins must implement to be inserted into
App