pub struct PluginBuildContext<'a> { /* private fields */ }Expand description
Plugin build context
Implementations
Sourceimpl PluginBuildContext<'_>
impl PluginBuildContext<'_>
Sourcepub fn register_system<S>(&mut self, stage: Stage, sys: S)
pub fn register_system<S>(&mut self, stage: Stage, sys: S)
Register a system to insert into the dispatcher. Systems will be run in the exact order of registration, and
they will be assigned name corresponding to its module path, e.g. game::something::MySystem.
Sourcepub fn register_system_deps<S>(
&mut self,
stage: Stage,
sys: S,
deps: &'static [&'static str],
)
pub fn register_system_deps<S>( &mut self, stage: Stage, sys: S, deps: &'static [&'static str], )
Register a system to insert into the dispatcher with dependencies. Systems will be run in the exact order of registration, and
they will be assigned name corresponding to its module path, e.g. game::something::MySystem.
Sourcepub fn insert_resource(&mut self, resource: impl Resource)
pub fn insert_resource(&mut self, resource: impl Resource)
Insert a resource into ECS world
Sourcepub fn with_component<C: Component, F: ComponentFactory + 'static>(
&mut self,
name: &'static str,
component_factory: F,
)
pub fn with_component<C: Component, F: ComponentFactory + 'static>( &mut self, name: &'static str, component_factory: F, )
Register a component in the ECS
Sourcepub fn event_sender(&self) -> Sender<AppEvent>
pub fn event_sender(&self) -> Sender<AppEvent>
Get an app event sender