Prelude module
Re-exports
pub use crate::app::App;pub use crate::app::AppBuilder;
Macros
- impl_
component_ factory - Create and implement a component factory for a component.
Structs
- Component
Registry - Registry of component name - component factory
Traits
- Component
Factory - All components must have a factory implementing this trait to be able created from a scene config.